require(lattice)
require(extrafont)
require(RColorBrewer)
require(mc2d) #triangular
require(VGAM) #rayleigh,pareto
require(fdrtool) #half-normal
require(Hmisc)

#set colors
cz1 <- c("#e31a1c","#377db8","#4daf4a","#984ea3")
cz2 <- c("#0a4444","#0f6666","#138888","#18aaaa")
cz3<- c("#fe9929","#ec7014","#cc4c02","#993404")
cz4<- c("#980043","#ce1256","#df65b0","#c994c7")
cz <- c(rev(cz1),cz2,rev(cz3),cz4)
lcz <- list(rev(cz1),cz2,rev(cz3),cz4)
darkgray<-"#575757"

#x is numeric vector and param is sigma parameter
Rayleigh <- function(x,param,xparam=0){
  prayleigh(x,param)
}

Exponential <- function(x,param,xparam=0){
  param <- 1/param
  pexp(x,param)
}

HalfNormal <- function(x,param,xparam=0){
  param <- sd2theta(param*sqrt(2))
  phalfnorm(x,param)
}

Triangular <- function(x,param,xparam=0){
  param <- 2*param
  ptriang(x,min=0,mode=param,max=param)
}

Gamma <- function(x,param,xparam){
  xparam <- as.numeric(xparam)
  param <-sqrt((xparam*(1+xparam))/(2.0*param*param))
  pgamma(x,shape=xparam,rate=param)
}

Lomax <- function(x,param,xparam){
  xparam <- as.numeric(xparam)
  param <- sqrt((-2+xparam)*(-1+xparam)*param*param)
  plomax(x,scale=param,shape3.q=xparam)
}

Pareto <- function(x,param,xparam){
  xparam <- as.numeric(xparam) # alpha
  param <- sqrt((2*param*param*(xparam-2))/xparam) #xmax
  ppareto(x, param, xparam)
}

plot.dist <- function(directory){
  

  lattice.options(default.args = list(as.table = TRUE))
  trellis.device(device="pdf", file="ecdf.pdf",
                 width=4.5, height=3.3, family="Helvetica")
  trellis.par.set(layout.heights = list(
    top.padding = 0,
    main=1,
    main.key.padding=0,
    key.top=0,
    key.axis.padding=0,
    axis.top=0.5,
    strip=1,
    panel=1,
    axis.panel=0,
    between=0,
    axis.bottom=1,
    axis.xlab.padding=0,
    xlab = 1,
    xlab.key.padding=0,
    key.bottom=0,
    key.sub.padding=0,
    sub = 0,
    bottom.padding=0.5
  ))
  trellis.par.set(layout.widths = list(
    left.padding = 0.2,
    axis.right = 0,
    axis.key.padding = 0,
    ylab.axis.padding=0,
    right.padding = 0.2
  ))
  trellis.par.set(fontsize = list(text = 9))
  p <- read.csv(paste(directory,"settings_summary.txt",sep=""),header = T)
  
  get.parameter <- function(d,s,p2){
    p[p$dist==d & p$sigma== s & p$param2==p2,]$param1
  }
  
  d <- read.csv(paste(directory,"dist_summary.txt",sep=""),header=T)
  d <- data.frame(subset(d,disc!=-1 & param!=3.2 & sigma!=0.5 &sigma!=0.75 & sigma!=3))
  d$dist <- factor(d$dist,c("Ray","Exp","Nor","Tri",
                            "Gam","Lom","Par"))
  
  d$dist <- factor(d$dist,labels=c("Rayleigh","Exponential","HalfNormal","Triangular",
                                   "Gamma","Lomax","Pareto"))
  strip.labels <- c("Rayleigh","Exponential","Half-Normal","Triangular","Gamma 1",
                    "Gamma 2", "Gamma 4", "Gamma 8","Lomax 2.4", "Lomax 2.6", 
                    "Lomax 2.8", "Lomax 3.0", "Pareto 2.4", "Pareto 2.6", "Pareto 2.8",
                    "Pareto 3.0")
  
  d$lab <- factor(interaction(d$dist,d$param))
  d$lab <- factor(d$lab, levels=c("Rayleigh.0","Exponential.0","HalfNormal.0","Triangular.0",
                  "Gamma.1","Gamma.2","Gamma.4","Gamma.8",
                  "Lomax.2.4","Lomax.2.6","Lomax.2.8","Lomax.3",
                  "Pareto.2.4","Pareto.2.6","Pareto.2.8","Pareto.3"),
                  labels=strip.labels)

  dists <- c("Rayleigh","Exponential","HalfNormal", "Triangular",
             "Gamma", "Gamma", "Gamma", "Gamma",
             "Lomax", "Lomax", "Lomax", "Lomax",
             "Pareto", "Pareto", "Pareto", "Pareto")
  
  alfs <- c(0,0,0,0,1,2,4,8,2.4,2.6,2.8,3.0,2.4,2.6,2.8,3.0)
  parameters <- c(1,1.5,2,4)
  lwdth <- seq(0.5,3, length.out = length(parameters))
  discrete <- Ecdf(~disc |factor(lab), data=d, group=sigma,label.curves=F,
                 layout=c(4,4),type="density",col=cz,xlim=c(0,10),
                 xlab = list("Dispersal Distance",cex=1),lty=1, border="black",subscripts=T,
                 ylab = list("Empirical Cumulative Distribution Function",cex=1),cex=1,
                 scales=list(tck=c(1,0),alternating=1, cex=0.75, x=list(at=c(2,4,6,8))),
                 par.settings=list(strip.background=list(col="gray")),
                 par.strip.text=list(cex=1,col="black"),
                 strip=strip.custom(factor.levels=strip.labels),
                 panel = function(x,col=col,subscripts,...){
                   dist <- dists[packet.number()]
                   alf <- alfs[packet.number()]
                   dx<- 10000
                   fun <- match.fun(dist)
                   
                   panel.Ecdf(x,subscripts,col=col[packet.number()],lwd=lwdth,...)
                   for(i in 1:length(parameters)){
                    adj.par <- get.parameter(as.character(dist),parameters[i],as.numeric(alf))
                    panel.curve(fun(x,adj.par,alf),type="l",col="black",lwd=0.5)
                   }
                 }
            )
  print(discrete)
  continuous<- Ecdf(~cont |factor(lab), data=d, group=sigma,label.curves=F,
            layout=c(4,4),type="density",col=cz,xlim=c(0,10),
            xlab = list("Dispersal Distance",cex=1),lty=1, border="black",subscripts=T,
            ylab = list("Empirical Cumulative Distribution Function",cex=1),cex=1,
            scales=list(tck=c(1,0),alternating=1, cex=0.75),
            par.settings=list(strip.background=list(col="gray")),
            par.strip.text=list(cex=1,col="black"),
            strip=strip.custom(factor.levels=strip.labels),
            panel = function(x,col=col,subscripts,...){
              dist <- dists[packet.number()]
              alf <- alfs[packet.number()]
              dx<- 10000
              fun <- match.fun(dist)
              
              panel.Ecdf(x,subscripts,col=col[packet.number()],lwd=3,...)
              for(i in 1:length(parameters)){
                adj.par <- get.parameter(as.character(dist),parameters[i],as.numeric(alf))
                panel.curve(fun(x,adj.par,alf),type="l",col="black",lwd=0.5)
              }
            }
  )
  print(continuous) 
  
  invisible(dev.off())
  
  embed_fonts("ecdf.pdf", options="-DPDFSETTINGS=/prepress")
}

plot.dist("./rawData/")
