#Set options
require(lattice)
require(extrafont)
require(RColorBrewer)
#set colors
cz1 <- c("#e31a1c","#377db8","#4daf4a","#984ea3")
cz2 <- c("#0a4444","#0f6666","#138888","#18aaaa")
cz3<- c("#fe9929","#ec7014","#cc4c02","#993404")
cz4<- c("#980043","#ce1256","#df65b0","#c994c7")
cz <- c(rev(cz1),cz2,rev(cz3),cz4)
asured <- rgb(153/255,0/255,51/255)
asublue <- rgb(0/255,142/255,214/255)
asudarkgrey <- rgb(79/255,85/255,87/255)
asugrey <- rgb(175/255,165/255,147/255)

#lattice options
lattice.options(default.args = list(as.table = TRUE))
trellis.device(device="pdf", file="slopeNb.pdf",
               width=6, height=3, family="Helvetica")
trellis.par.set(layout.heights = list(
  top.padding = 1.2,
  main=1,
  main.key.padding=0,
  key.top=0,
  key.axis.padding=0,
  axis.top=0.5,
  strip=1,
  panel=1,
  axis.panel=0,
  between=0,
  axis.bottom=1,
  axis.xlab.padding=0,
  xlab = 1,
  xlab.key.padding=0,
  key.bottom=0,
  key.sub.padding=0,
  sub = 0,
  bottom.padding=0.5
))
trellis.par.set(layout.widths = list(
  left.padding = 0.2,
  axis.right = 0,
  axis.key.padding = 0,
  ylab.axis.padding=0,
  right.padding = 1.2
))
trellis.par.set(fontsize = list(text = 9))

d <- read.csv("./rawData/slopeNb.txt",header=T,sep=",")
d <- data.frame(subset(d, param!=3.2 & sigma!=0.5 & sigma!=0.75 & sigma!=3))
d$dist <- factor(d$dist,c("Ray","Exp","Nor","Tri",
                          "Gam","Lom","Par"))

strip.labels <- c("1", "1.5", "2", "4")
d$lab <- interaction(d$dist,d$param)

d$lab <- factor(d$lab,levels = rev(c("Ray.0", "Exp.0", "Nor.0", "Tri.0", 
                                 "Gam.1", "Gam.2", "Gam.4", "Gam.8",
                                 "Lom.2.4", "Lom.2.6", "Lom.2.8", "Lom.3",
                                 "Par.2.4", "Par.2.6", "Par.2.8", "Par.3")),
                labels=rev(c("Rayleigh","Exponential","Half Normal","Triangular",
                         "Gamma 1","Gamma 2","Gamma 4","Gamma 8",
                         "Lomax 2.4", "Lomax 2.6", "Lomax 2.8", "Lomax 3.0",
                         "Pareto 2.4", "Pareto 2.6", "Pareto 2.8", "Pareto 3.0")))

a <- xyplot(lab~rnb|factor(sigma),data=d,cex=1,lwd=1,col=cz,pch=20,
            xlab = list(expression(paste("Slope ", (2/N[b(a[r])]), " Relative to Expected")), cex=1),
            ylab = list("Dispersal Distribution", cex=1),layout=c(4,1),
            xlim=c(-4,4),
            scales=list(tck=c(1,0),alternating=1,cex=0.75,x=list(at=c(-2,0,2))),
            par.settings=list(strip.background=list(col="grey")),
            par.strip.text=list(cex=1,col="black"),
            #strip=strip.custom(factor.levels=x.labels),
            panel = function(x,y,subscripts,col,pch,...){
              low <- d$lower[subscripts]
              high <- d$upper[subscripts]
              panel.abline(v=0,col=asugrey,lty=1)
              panel.arrows(low,y,high,y, code=3, length=0, lwd=3, col=col)
              panel.xyplot(x,y,col=col,pch=pch, ...)
            })




print(a)


invisible(dev.off())

embed_fonts("slopeNb.pdf", options="-DPDFSETTINGS=/prepress")





