require(lattice)
require(extrafont)
require(RColorBrewer)

plot.ar <- function(d){
  #set colors
  cz1 <- c("#e31a1c","#377db8","#4daf4a","#984ea3")
  cz2 <- c("#0a4444","#0f6666","#138888","#18aaaa")
  cz3<- c("#fe9929","#ec7014","#cc4c02","#993404")
  cz4<- c("#980043","#ce1256","#df65b0","#c994c7")
  cz <- c(rev(cz1),cz2,rev(cz3),cz4)
  lcz <- list(rev(cz1),cz2,rev(cz3),cz4)
  
  lattice.options(default.args = list(as.table = TRUE))
  
  trellis.device(device="pdf", file="ar.pdf",
                 width=3.33, height=3.33, family="Helvetica")
  trellis.par.set(layout.heights = list(
    top.padding = 0.2,
    main=0,
    main.key.padding=0,
    key.top=0,
    key.axis.padding=0,
    axis.top=0,
    strip=1,
    panel=1,
    axis.panel=0,
    between=0,
    axis.bottom=1,
    axis.xlab.padding=0,
    xlab = 1,
    xlab.key.padding=0,
    key.bottom=0,
    key.sub.padding=0,
    sub = 0,
    bottom.padding=0.5
  ))
  trellis.par.set(layout.widths = list(
    left.padding = 0.2,
    axis.right = 0,
    axis.key.padding = 0,
    ylab.axis.padding=0,
    right.padding = 0.2
  ))
  trellis.par.set(fontsize = list(text = 9))
  
  ibd <- read.csv(paste(d,"IBD_summary.txt",sep=""), header=TRUE)
  pibd <- read.csv(paste(d,"pIBD_summary.txt",sep=""), header=TRUE)
  gibd <- read.csv(paste(d,"gIBD_summary.txt",sep=""), header=TRUE)
  
  ibd$v <- "all"
  pibd$v <- "b.parental"
  gibd$v <- "c.grandparental"
  
  ibd <- rbind(ibd,pibd,gibd)
  ibd <- data.frame(subset(ibd,sigma!=0.5 &sigma!=0.75 & sigma!=3 & r!=0))
  s1 <- data.frame(subset(ibd,dist=="Ray"|dist=="Exp"|dist=="Nor"|dist=="Tri"))
  s2 <- data.frame(subset(ibd,dist=="Gam"))
  s3 <- data.frame(subset(ibd,dist=="Lom"))
  s4 <- data.frame(subset(ibd,dist=="Par"))
  
  s1$g <- "a.original"
  s2$g <- "b.gamma"
  s3$g <- "c.lomax"
  s4$g <- "d.pareto"
  s <- rbind(s1,s2,s3,s4)
  
  s$lab <- interaction(s$dist,s$param)
  s$lab <- factor(s$lab,levels=c("Ray.0","Exp.0","Nor.0","Tri.0",
                                 "Gam.1","Gam.2","Gam.4","Gam.8",
                                 "Lom.2.4","Lom.2.6","Lom.2.8","Lom.3",
                                 "Par.2.4","Par.2.6","Par.2.8","Par.3"),
                  labels=c("Rayleigh","Exponential","Half-Normal","Triangular",
                           "Gamma 1", "Gamma 2", "Gamma 4","Gamma 8",
                           "Lomax 2.4","Lomax 2.6","Lomax 2.8","Lomax 3.0",
                           "Pareto 2.4", "Pareto 2.6", "Pareto 2.8", "Pareto 3.0"))
  ibdv <- split(s,s$v)
  
  strip.labels <- c("1","1.5","2","4")
  strip.labels <- rep(strip.labels,6)
  
  l1 <- c("Ray.0","Exp.0","Nor.0","Tri.0")
  l2 <- c("Gam.1","Gam.2","Gam.4","Gam.8")
  l3 <- c("Lom.2.4","Lom.2.6","Lom.2.8","Lom.3.0")
  l4 <- c("Par.2.4","Par.2.6","Par.2.8","Par.3.0")
  lev <- list(l1,l2,l3,l4)
  
  ll1<- c("Rayleigh","Exponential","Half-Normal","Triangular")
  ll2<- c("Gamma 1", "Gamma 2", "Gamma 4","Gamma 8")
  ll3<- c("Lomax 2.4","Lomax 2.6","Lomax 2.8","Lomax 3.0")
  ll4<- c("Pareto 2.4", "Pareto 2.6", "Pareto 2.8", "Pareto 3.0")
  llev <- list(ll1,ll2,ll3,ll4)
  
  yl <- list(c(-.1,1.5),c(-0.1,0.95),c(-0.1,0.95))
  xl <- list(c(-2,65),c(-2,6),c(-2,6))
  al <- list(c(1,5,25),c(1,2,3,4,5),c(1,2,3,4,5))
  bgColors <- c("black", "green4", "blue", "red", "purple", "yellow")
  txtColors <- c("white", "yellow", "white", "white", "green", "red")
  myStripStyle <- function(which.panel, factor.levels, ...) {
    if(which.panel<= 4){
      panel.rect(0, 0, 1, 1, col = "gray", border = 1)
      panel.text(x = 0.5, y = 0.5, cex=1, font=2, lab = strip.labels[which.panel],
                 col = "black")
    }
    else
      F
  }
  
  posxl <- c(0.1,0.15,0.15)
  posyl <- list(seq(0.6,1.36,length.out=4),seq(0.4,0.8,length.out=4),
             seq(0.4,0.8,length.out=4))
  for(i in 1:length(ibdv)){
    data <- ibdv[[i]]
    data$stp <- interaction(data$sigma,data$v,data$g)
    ylim <- yl[[i]]
    xlim <- xl[[i]]
    at <- al[[i]]
    posx <- posxl[i]
    posy <- posyl[[i]]
    g <- xyplot(a~r | factor(stp), data=data, groups=lab,
                layout=c(4,4),cex=1,type="l",lwd=3,
                xlab = list("Log Distance (Lattice Units)",cex=1),
                ylab = list(expression(bar(a[r])),cex = 1),
                scales=list(tck=c(1,0),alternating=1, cex=0.75,
                            x=list(log=T,at=at),
                            y=list(at=c(0,0.4,0.8,1.2))),
                col=cz,ylim=ylim,xlim=xlim,
                strip=myStripStyle,
                abline=list(h=0,lty=2,col="gray",lwd=2),
                panel = function(x,y,...){
                  panel.xyplot(x,y,...)
                  if(current.column()==4){
                    r <- current.row()
                    lab <- llev[[r]]
                    col <- lcz[[r]]
                    #posx <- 0.5
                    #posy <- seq(0.6,1.2,length.out=4)
                    #if(r==3){
                      #posy <- seq(0.2,1,length.out=4)
                    #}
                    panel.text(x=posx,y=posy[4],labels=lab[1],col=col[1],cex=0.75,pos=4)
                    panel.text(x=posx,y=posy[3],labels=lab[2],col=col[2],cex=0.75,pos=4)
                    panel.text(x=posx,y=posy[2],labels=lab[3],col=col[3],cex=0.75,pos=4)
                    panel.text(x=posx,y=posy[1],labels=lab[4],col=col[4],cex=0.75,pos=4)
                  }
                }
    )
    print(g)
  }
  invisible(dev.off())
  
  embed_fonts("ar.pdf", options="-DPDFSETTINGS=/prepress")
}

plot.ar("./rawData/")



