#Set options
require(lattice)
require(extrafont)
require(RColorBrewer)
#set colors
cz1 <- c("#e31a1c","#377db8","#4daf4a","#984ea3")
cz2 <- c("#0a4444","#0f6666","#138888","#18aaaa")
cz3<- c("#fe9929","#ec7014","#cc4c02","#993404")
cz4<- c("#980043","#ce1256","#df65b0","#c994c7")
cz <- c(rev(cz1),cz2,rev(cz3),cz4)
lcz <- list(rev(cz1),cz2,rev(cz3),cz4)
asured <- rgb(153/255,0/255,51/255)
asublue <- rgb(0/255,142/255,214/255)
asudarkgrey <- rgb(79/255,85/255,87/255)
asugrey <- rgb(175/255,165/255,147/255)

plot.s2 <- function(directory){
  

  d <- read.csv(paste(directory,"dem_cat.txt",sep=""),header=T)
  
  d <- data.frame(subset(d, param!=3.2 & sigma!=0.5 & sigma!=0.75 & sigma!=3))
  d$dist <- factor(d$dist,c("Ray","Exp","Nor","Tri",
                            "Gam","Lom","Par"))
  
  strip.labels <- c("1", "1.5", "2", "4")
  d$lab <- interaction(d$dist,d$param)
  d$lab <- factor(d$lab,levels = c("Ray.0", "Exp.0", "Nor.0", "Tri.0", 
                                   "Gam.1", "Gam.2", "Gam.4", "Gam.8",
                                   "Lom.2.4", "Lom.2.6", "Lom.2.8", "Lom.3",
                                   "Par.2.4", "Par.2.6", "Par.2.8", "Par.3"),
                  labels=c("Rayleigh","Exponential","Half Normal","Triangular",
                           "Gamma 1","Gamma 2","Gamma 4","Gamma 8",
                           "Lomax 2.4", "Lomax 2.6", "Lomax 2.8", "Lomax 3.0",
                           "Pareto 2.4", "Pareto 2.6", "Pareto 2.8", "Pareto 3.0"))
  
  #lattice options
  lattice.options(default.args = list(as.table = TRUE))
  trellis.device(device="pdf", file="s2.pdf",
                 width=2, height=4.2, family="Helvetica")
  trellis.par.set(layout.heights = list(
    top.padding = 0,
    main=1,
    main.key.padding=0,
    key.top=0,
    key.axis.padding=0,
    axis.top=0.3,
    strip=1,
    panel=1,
    axis.panel=1,
    between=0,
    axis.bottom=1,
    axis.xlab.padding=0,
    xlab = 1,
    xlab.key.padding=0,
    key.bottom=0,
    key.sub.padding=0,
    sub = 0,
    bottom.padding=0.5
  ))
  trellis.par.set(layout.widths = list(
    left.padding = 0.2,
    axis.right = 0,
    axis.key.padding = 0,
    ylab.axis.padding=0,
    right.padding = 0.2
  ))
  trellis.par.set(fontsize = list(text = 9))
  
  s.line <- c(1,2.25,4,16)
  
  b <- bwplot(sigma2~factor(lab)|factor(sigma),data=d,cex=.9,lwd=1,pch='|',
              xlab = list("Dispersal Distribution", cex=1),
              ylab = list(bquote(paste("Observed ", s^2," (Log Scale)")), cex=1),
              layout=c(1,4),col=cz,
              par.settings=list(strip.background=list(col="gray"),
                                plot.symbol=list(col="gray",pch=20,cex=.2),
                                box.dot=list(col=cz,lwd=2),
                                box.rectangle=list(col=cz,lwd=2),
                                box.umbrella=list(col=cz,lwd=2)),
              scales=list(tck=c(1,0),alternating=1,cex=0.75,
                          y=list(log=10,at=c(0.1,1,10,100),relation="free",rot=360),
                          x=list(rot=70,cex=0.75)),
              par.strip.text=list(cex=1,col="black"),
              panel = function(x,y,...) {
                panel.abline(h=log(s.line[packet.number()],10),col="gray",lty=1,lwd=2)
                panel.bwplot(x,y,...)
                
              })
  print(b)
  
  invisible(dev.off())
  
  embed_fonts("s2.pdf", options="-DPDFSETTINGS=/prepress")
}

plot.s2("./rawData/")

